# Copyright 2018- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class SaleOrder(models.Model):
    _inherit = "sale.order"

    untaxed_amount_to_invoice = fields.Monetary(
        string="Remains to invoice (untaxed)",
        compute="_compute_untaxed_amount_to_invoice",
        store=True,
        readonly=True,
    )

    @api.depends("order_line.untaxed_amount_to_invoice")
    def _compute_untaxed_amount_to_invoice(self):
        """
        Compute the amount (untaxed) that remains to be invoiced
        from sale order
        """
        for order in self:
            order.untaxed_amount_to_invoice = sum(
                order.order_line.mapped("untaxed_amount_to_invoice")
            )
